@@ -21,7 +21,7 @@ class ActionEdit(BronoteAction):
             'short': '-s',
             'action': 'store_true',
             'help': 'Search for a file instead of using a hard path.'
-        }
+        },
     }
 
     def init(self, args):
@@ -41,6 +41,13 @@ class ActionEdit(BronoteAction):
             search_result = self.find_note(self.path.name)
             if search_result:
                 self.path = search_result
+            else:
+                # If there really weren't any known files
+                # create the parent directory first if it's absent
+                for parent in self.path.parents:
+                    if not parent.exists():
+                        os.makedirs(parent)
+                        break
 
         try:
             os.chdir(self.cfg.notes_dir)
